<?php

namespace Drupal\psn_public_trophies\Form;

use Drupal\Core\Form\ConfigFormBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Form\FormStateInterface;
use Drupal\psn_public_trophies\Component\DrupalPSNPublicTrophies;
use Drupal\Component\Serialization\Json;

/**
 * Edit config variable form.
 */
class PSNPublicTrophiesSettingsForm extends ConfigFormBase {
    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'psn_public_trophies_admin_settings_form';
    }

    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames() {
        return [
            'psn_public_trophies.settings',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state, Request $request = NULL) {
        $config = $this->config('psn_public_trophies.settings');

        $form['psn_id'] = array(
            '#type' => 'textfield',
            '#title' => t('PSN ID'),
            '#description' => t('PSN ID from Playstation'),
            '#default_value' => $config->get('psn_id'),
        );

        if ($psn_id = $config->get('psn_id')) {
            $psn_public_trophies = new DrupalPSNPublicTrophies($psn_id);
            $form['info'] = array(
                '#type' => 'markup',
                '#markup' => '<div><strong>Profile</strong><p><code>' . Json::encode($psn_public_trophies->getProfile()) . '</code></p></div><div><strong>Trophies</strong><p><code>' . Json::encode($psn_public_trophies->getTrophies()) . '</code></p></div>'
            );
        }

        return parent::buildForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        $values = $form_state->getValues();
        $this->config('psn_public_trophies.settings')
            ->set('psn_id', $values['psn_id'])
            ->save();

        parent::submitForm($form, $form_state);
    }
}
