<?php

namespace Drupal\psn_public_trophies\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\psn_public_trophies\Component\DrupalPSNPublicTrophies;
use Drupal\Component\Serialization\Json;

/**
 * Provides a 'PSNPublicTrophiesProfileBlock' Block.
 *
 * @Block(
 *   id = "psn_public_trophies_profile_block",
 *   admin_label = @Translation("PSN Public Trophies Profile Block"),
 *   category = @Translation("PSN Public Trophies"),
 * )
 */
class PSNPublicTrophiesProfileBlock extends BlockBase implements BlockPluginInterface {
	/**
	 * {@inheritdoc}
	 */
	public function build() {
		$config = $this->getConfiguration();

		$psn_public_trophies = new DrupalPSNPublicTrophies($config['psn_id']);

		$profile = $psn_public_trophies->getProfile();
		$progress_html_arr = array(
			'#theme' => 'progress_bar',
			'#percent' => $profile->progress
		);

		$trophies = (array) $profile->trophies;
		$trophies_html_arr = array(
			'#theme' => 'psn_public_trophies_trophies_items',
			'#trophies' => $trophies
		);

		$game_trophies = $psn_public_trophies->getTrophies();
		$game_trophies_arr = [];
		foreach ($game_trophies->list as $item) {
			$game_trophies_arr[] = [
				'item' => $item,
				'progress' => [
					'#theme' => 'progress_bar',
					'#percent' => $item->progress
				],
				'trophies' => [
					'#theme' => 'psn_public_trophies_trophies_items',
					'#trophies' => (array) $item->trophies
				]
			];
		}
		$game_trophies_html_arr = array(
			'#theme' => 'psn_public_trophies_trophies',
			'#trophies' => $game_trophies,
			'#rendered' => array('game_trophies' => $game_trophies_arr)
		);

		return array(
			'#theme' => 'psn_public_trophies_profile',
			'#profile' => $profile,
			'#trophies' => $game_trophies,
			'#rendered' => array(
				'progress' => $progress_html_arr,
				'trophies' => $trophies_html_arr,
				'game_trophies' => $game_trophies_html_arr
			)
		);
	}

	/**
	 * {@inheritdoc}
	 */
	public function blockForm($form, FormStateInterface $form_state) {
		$form = parent::blockForm($form, $form_state);

		$config = $this->getConfiguration();

		$form['psn_id'] = array(
	      '#type' => 'textfield',
	      '#title' => $this->t('PSN ID'),
	      '#default_value' => isset($config['psn_id']) ? $config['psn_id'] : NULL,
	    );
	    return $form;
	}

	/**
	 * {@inheritdoc}
	 */
	public function blockSubmit($form, FormStateInterface $form_state) {
		parent::blockSubmit($form, $form_state);

		$values = $form_state->getValues();
    	$this->configuration['psn_id'] = $values['psn_id'];
	}
}